=======
History
=======


0.1.0 (27 July 2016)
--------------------

* First git checkin of peripheral ISLE entries, with configuration
  managed upstream.
  
* deployed with automatic push to pypi by travis.
